==> notebook-clj-0.0.1.jar: public/cljs-runtime/pinkgorilla.storage.direct.gist.js <==
goog.provide('pinkgorilla.storage.direct.gist');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('pinkgorilla.storage.direct.protocol');
goog.require('pinkgorilla.storage.gist');
(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$protocol$Direct$ = cljs.core.PROTOCOL_SENTINEL);

(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$protocol$Direct$load_url$arity$2 = (function (self,base_path){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.direct.gist","/tmp/form-init2571683730222641663.clj",11,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["gist-storage.load-url for storage settings",self__$1], null);
}),null)),null,943807499);

return ["https://api.github.com/gists/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.id)].join('');
}));

(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$protocol$Direct$decode_content$arity$2 = (function (self,response){
var self__$1 = this;
var files = cljs.core.get.cljs$core$IFn$_invoke$arity$2(response,"files");
var name = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2((1),cljs.core.count(files)))?cljs.core.first(cljs.core.keys(files)):self__$1.filename);
var content = cljs.core.get.cljs$core$IFn$_invoke$arity$2(cljs.core.get.cljs$core$IFn$_invoke$arity$2(files,name),"content");
return content;
}));

//# sourceMappingURL=pinkgorilla.storage.direct.gist.js.map

==> notebook-clj-0.0.2.jar: public/cljs-runtime/pinkgorilla.storage.direct.gist.js <==
goog.provide('pinkgorilla.storage.direct.gist');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('pinkgorilla.storage.direct.protocol');
goog.require('pinkgorilla.storage.gist');
(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$protocol$Direct$ = cljs.core.PROTOCOL_SENTINEL);

(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$protocol$Direct$load_url$arity$2 = (function (self,base_path){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.direct.gist","/tmp/form-init5480154391856654582.clj",11,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["gist-storage.load-url for storage settings",self__$1], null);
}),null)),null,-2071178474);

return ["https://api.github.com/gists/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.id)].join('');
}));

(pinkgorilla.storage.gist.StorageGist.prototype.pinkgorilla$storage$direct$protocol$Direct$decode_content$arity$2 = (function (self,response){
var self__$1 = this;
var files = cljs.core.get.cljs$core$IFn$_invoke$arity$2(response,"files");
var name = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2((1),cljs.core.count(files)))?cljs.core.first(cljs.core.keys(files)):self__$1.filename);
var content = cljs.core.get.cljs$core$IFn$_invoke$arity$2(cljs.core.get.cljs$core$IFn$_invoke$arity$2(files,name),"content");
return content;
}));

//# sourceMappingURL=pinkgorilla.storage.direct.gist.js.map
